@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     AllowMessagesType,
     AppInstanceUserEndpointTypeType,
@@ -91,109 +93,99 @@ __all__ = (
 AppInstanceAdminSummaryTypeDef = TypedDict(
     "AppInstanceAdminSummaryTypeDef",
     {
-        "Admin": "IdentityTypeDef",
+        "Admin": NotRequired["IdentityTypeDef"],
     },
-    total=False,
 )
 
 AppInstanceAdminTypeDef = TypedDict(
     "AppInstanceAdminTypeDef",
     {
-        "Admin": "IdentityTypeDef",
-        "AppInstanceArn": str,
-        "CreatedTimestamp": datetime,
+        "Admin": NotRequired["IdentityTypeDef"],
+        "AppInstanceArn": NotRequired[str],
+        "CreatedTimestamp": NotRequired[datetime],
     },
-    total=False,
 )
 
 AppInstanceRetentionSettingsTypeDef = TypedDict(
     "AppInstanceRetentionSettingsTypeDef",
     {
-        "ChannelRetentionSettings": "ChannelRetentionSettingsTypeDef",
+        "ChannelRetentionSettings": NotRequired["ChannelRetentionSettingsTypeDef"],
     },
-    total=False,
 )
 
 AppInstanceSummaryTypeDef = TypedDict(
     "AppInstanceSummaryTypeDef",
     {
-        "AppInstanceArn": str,
-        "Name": str,
-        "Metadata": str,
+        "AppInstanceArn": NotRequired[str],
+        "Name": NotRequired[str],
+        "Metadata": NotRequired[str],
     },
-    total=False,
 )
 
 AppInstanceTypeDef = TypedDict(
     "AppInstanceTypeDef",
     {
-        "AppInstanceArn": str,
-        "Name": str,
-        "CreatedTimestamp": datetime,
-        "LastUpdatedTimestamp": datetime,
-        "Metadata": str,
+        "AppInstanceArn": NotRequired[str],
+        "Name": NotRequired[str],
+        "CreatedTimestamp": NotRequired[datetime],
+        "LastUpdatedTimestamp": NotRequired[datetime],
+        "Metadata": NotRequired[str],
     },
-    total=False,
 )
 
 AppInstanceUserEndpointSummaryTypeDef = TypedDict(
     "AppInstanceUserEndpointSummaryTypeDef",
     {
-        "AppInstanceUserArn": str,
-        "EndpointId": str,
-        "Name": str,
-        "Type": AppInstanceUserEndpointTypeType,
-        "AllowMessages": AllowMessagesType,
-        "EndpointState": "EndpointStateTypeDef",
+        "AppInstanceUserArn": NotRequired[str],
+        "EndpointId": NotRequired[str],
+        "Name": NotRequired[str],
+        "Type": NotRequired[AppInstanceUserEndpointTypeType],
+        "AllowMessages": NotRequired[AllowMessagesType],
+        "EndpointState": NotRequired["EndpointStateTypeDef"],
     },
-    total=False,
 )
 
 AppInstanceUserEndpointTypeDef = TypedDict(
     "AppInstanceUserEndpointTypeDef",
     {
-        "AppInstanceUserArn": str,
-        "EndpointId": str,
-        "Name": str,
-        "Type": AppInstanceUserEndpointTypeType,
-        "ResourceArn": str,
-        "EndpointAttributes": "EndpointAttributesTypeDef",
-        "CreatedTimestamp": datetime,
-        "LastUpdatedTimestamp": datetime,
-        "AllowMessages": AllowMessagesType,
-        "EndpointState": "EndpointStateTypeDef",
+        "AppInstanceUserArn": NotRequired[str],
+        "EndpointId": NotRequired[str],
+        "Name": NotRequired[str],
+        "Type": NotRequired[AppInstanceUserEndpointTypeType],
+        "ResourceArn": NotRequired[str],
+        "EndpointAttributes": NotRequired["EndpointAttributesTypeDef"],
+        "CreatedTimestamp": NotRequired[datetime],
+        "LastUpdatedTimestamp": NotRequired[datetime],
+        "AllowMessages": NotRequired[AllowMessagesType],
+        "EndpointState": NotRequired["EndpointStateTypeDef"],
     },
-    total=False,
 )
 
 AppInstanceUserSummaryTypeDef = TypedDict(
     "AppInstanceUserSummaryTypeDef",
     {
-        "AppInstanceUserArn": str,
-        "Name": str,
-        "Metadata": str,
+        "AppInstanceUserArn": NotRequired[str],
+        "Name": NotRequired[str],
+        "Metadata": NotRequired[str],
     },
-    total=False,
 )
 
 AppInstanceUserTypeDef = TypedDict(
     "AppInstanceUserTypeDef",
     {
-        "AppInstanceUserArn": str,
-        "Name": str,
-        "Metadata": str,
-        "CreatedTimestamp": datetime,
-        "LastUpdatedTimestamp": datetime,
+        "AppInstanceUserArn": NotRequired[str],
+        "Name": NotRequired[str],
+        "Metadata": NotRequired[str],
+        "CreatedTimestamp": NotRequired[datetime],
+        "LastUpdatedTimestamp": NotRequired[datetime],
     },
-    total=False,
 )
 
 ChannelRetentionSettingsTypeDef = TypedDict(
     "ChannelRetentionSettingsTypeDef",
     {
-        "RetentionDays": int,
+        "RetentionDays": NotRequired[int],
     },
-    total=False,
 )
 
 CreateAppInstanceAdminRequestRequestTypeDef = TypedDict(
@@ -213,28 +205,15 @@ CreateAppInstanceAdminResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateAppInstanceRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateAppInstanceRequestRequestTypeDef",
+CreateAppInstanceRequestRequestTypeDef = TypedDict(
+    "CreateAppInstanceRequestRequestTypeDef",
     {
         "Name": str,
         "ClientRequestToken": str,
+        "Metadata": NotRequired[str],
+        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
-_OptionalCreateAppInstanceRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateAppInstanceRequestRequestTypeDef",
-    {
-        "Metadata": str,
-        "Tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateAppInstanceRequestRequestTypeDef(
-    _RequiredCreateAppInstanceRequestRequestTypeDef, _OptionalCreateAppInstanceRequestRequestTypeDef
-):
-    pass
-
 
 CreateAppInstanceResponseTypeDef = TypedDict(
     "CreateAppInstanceResponseTypeDef",
@@ -244,31 +223,17 @@ CreateAppInstanceResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateAppInstanceUserRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateAppInstanceUserRequestRequestTypeDef",
+CreateAppInstanceUserRequestRequestTypeDef = TypedDict(
+    "CreateAppInstanceUserRequestRequestTypeDef",
     {
         "AppInstanceArn": str,
         "AppInstanceUserId": str,
         "Name": str,
         "ClientRequestToken": str,
+        "Metadata": NotRequired[str],
+        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
-_OptionalCreateAppInstanceUserRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateAppInstanceUserRequestRequestTypeDef",
-    {
-        "Metadata": str,
-        "Tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateAppInstanceUserRequestRequestTypeDef(
-    _RequiredCreateAppInstanceUserRequestRequestTypeDef,
-    _OptionalCreateAppInstanceUserRequestRequestTypeDef,
-):
-    pass
-
 
 CreateAppInstanceUserResponseTypeDef = TypedDict(
     "CreateAppInstanceUserResponseTypeDef",
@@ -370,45 +335,21 @@ DescribeAppInstanceUserResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredEndpointAttributesTypeDef = TypedDict(
-    "_RequiredEndpointAttributesTypeDef",
+EndpointAttributesTypeDef = TypedDict(
+    "EndpointAttributesTypeDef",
     {
         "DeviceToken": str,
+        "VoipDeviceToken": NotRequired[str],
     },
 )
-_OptionalEndpointAttributesTypeDef = TypedDict(
-    "_OptionalEndpointAttributesTypeDef",
-    {
-        "VoipDeviceToken": str,
-    },
-    total=False,
-)
 
-
-class EndpointAttributesTypeDef(
-    _RequiredEndpointAttributesTypeDef, _OptionalEndpointAttributesTypeDef
-):
-    pass
-
-
-_RequiredEndpointStateTypeDef = TypedDict(
-    "_RequiredEndpointStateTypeDef",
+EndpointStateTypeDef = TypedDict(
+    "EndpointStateTypeDef",
     {
         "Status": EndpointStatusType,
+        "StatusReason": NotRequired[EndpointStatusReasonType],
     },
 )
-_OptionalEndpointStateTypeDef = TypedDict(
-    "_OptionalEndpointStateTypeDef",
-    {
-        "StatusReason": EndpointStatusReasonType,
-    },
-    total=False,
-)
-
-
-class EndpointStateTypeDef(_RequiredEndpointStateTypeDef, _OptionalEndpointStateTypeDef):
-    pass
-
 
 GetAppInstanceRetentionSettingsRequestRequestTypeDef = TypedDict(
     "GetAppInstanceRetentionSettingsRequestRequestTypeDef",
@@ -429,34 +370,19 @@ GetAppInstanceRetentionSettingsResponseTypeDef = TypedDict(
 IdentityTypeDef = TypedDict(
     "IdentityTypeDef",
     {
-        "Arn": str,
-        "Name": str,
+        "Arn": NotRequired[str],
+        "Name": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredListAppInstanceAdminsRequestRequestTypeDef = TypedDict(
-    "_RequiredListAppInstanceAdminsRequestRequestTypeDef",
+ListAppInstanceAdminsRequestRequestTypeDef = TypedDict(
+    "ListAppInstanceAdminsRequestRequestTypeDef",
     {
         "AppInstanceArn": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListAppInstanceAdminsRequestRequestTypeDef = TypedDict(
-    "_OptionalListAppInstanceAdminsRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListAppInstanceAdminsRequestRequestTypeDef(
-    _RequiredListAppInstanceAdminsRequestRequestTypeDef,
-    _OptionalListAppInstanceAdminsRequestRequestTypeDef,
-):
-    pass
-
 
 ListAppInstanceAdminsResponseTypeDef = TypedDict(
     "ListAppInstanceAdminsResponseTypeDef",
@@ -468,28 +394,14 @@ ListAppInstanceAdminsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListAppInstanceUserEndpointsRequestRequestTypeDef = TypedDict(
-    "_RequiredListAppInstanceUserEndpointsRequestRequestTypeDef",
+ListAppInstanceUserEndpointsRequestRequestTypeDef = TypedDict(
+    "ListAppInstanceUserEndpointsRequestRequestTypeDef",
     {
         "AppInstanceUserArn": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListAppInstanceUserEndpointsRequestRequestTypeDef = TypedDict(
-    "_OptionalListAppInstanceUserEndpointsRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListAppInstanceUserEndpointsRequestRequestTypeDef(
-    _RequiredListAppInstanceUserEndpointsRequestRequestTypeDef,
-    _OptionalListAppInstanceUserEndpointsRequestRequestTypeDef,
-):
-    pass
-
 
 ListAppInstanceUserEndpointsResponseTypeDef = TypedDict(
     "ListAppInstanceUserEndpointsResponseTypeDef",
@@ -500,28 +412,14 @@ ListAppInstanceUserEndpointsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListAppInstanceUsersRequestRequestTypeDef = TypedDict(
-    "_RequiredListAppInstanceUsersRequestRequestTypeDef",
+ListAppInstanceUsersRequestRequestTypeDef = TypedDict(
+    "ListAppInstanceUsersRequestRequestTypeDef",
     {
         "AppInstanceArn": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListAppInstanceUsersRequestRequestTypeDef = TypedDict(
-    "_OptionalListAppInstanceUsersRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListAppInstanceUsersRequestRequestTypeDef(
-    _RequiredListAppInstanceUsersRequestRequestTypeDef,
-    _OptionalListAppInstanceUsersRequestRequestTypeDef,
-):
-    pass
-
 
 ListAppInstanceUsersResponseTypeDef = TypedDict(
     "ListAppInstanceUsersResponseTypeDef",
@@ -536,10 +434,9 @@ ListAppInstanceUsersResponseTypeDef = TypedDict(
 ListAppInstancesRequestRequestTypeDef = TypedDict(
     "ListAppInstancesRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListAppInstancesResponseTypeDef = TypedDict(
@@ -583,32 +480,18 @@ PutAppInstanceRetentionSettingsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
-    "_RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef",
+RegisterAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
+    "RegisterAppInstanceUserEndpointRequestRequestTypeDef",
     {
         "AppInstanceUserArn": str,
         "Type": AppInstanceUserEndpointTypeType,
         "ResourceArn": str,
         "EndpointAttributes": "EndpointAttributesTypeDef",
         "ClientRequestToken": str,
+        "Name": NotRequired[str],
+        "AllowMessages": NotRequired[AllowMessagesType],
     },
 )
-_OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
-    "_OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef",
-    {
-        "Name": str,
-        "AllowMessages": AllowMessagesType,
-    },
-    total=False,
-)
-
-
-class RegisterAppInstanceUserEndpointRequestRequestTypeDef(
-    _RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef,
-    _OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef,
-):
-    pass
-
 
 RegisterAppInstanceUserEndpointResponseTypeDef = TypedDict(
     "RegisterAppInstanceUserEndpointResponseTypeDef",
@@ -671,29 +554,15 @@ UpdateAppInstanceResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateAppInstanceUserEndpointRequestRequestTypeDef",
+UpdateAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
+    "UpdateAppInstanceUserEndpointRequestRequestTypeDef",
     {
         "AppInstanceUserArn": str,
         "EndpointId": str,
+        "Name": NotRequired[str],
+        "AllowMessages": NotRequired[AllowMessagesType],
     },
 )
-_OptionalUpdateAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateAppInstanceUserEndpointRequestRequestTypeDef",
-    {
-        "Name": str,
-        "AllowMessages": AllowMessagesType,
-    },
-    total=False,
-)
-
-
-class UpdateAppInstanceUserEndpointRequestRequestTypeDef(
-    _RequiredUpdateAppInstanceUserEndpointRequestRequestTypeDef,
-    _OptionalUpdateAppInstanceUserEndpointRequestRequestTypeDef,
-):
-    pass
-
 
 UpdateAppInstanceUserEndpointResponseTypeDef = TypedDict(
     "UpdateAppInstanceUserEndpointResponseTypeDef",
